%global pypi_name tqdm

%bcond_with tests

Name:           python-%{pypi_name}
Version:        4.67.1
Release:        %mkrel 4
Summary:        A Fast, Extensible Progress Meter
Group:          Development/Python
# see PACKAGE-LICENSING for more info
License:        MPLv2.0 and MIT
URL:            https://tqdm.github.io/
Source0:        %{pypi_source}
BuildArch:      noarch
BuildRequires:  pyproject-rpm-macros
BuildRequires:  python3-devel
%if %{with tests}
BuildRequires:  python3dist(coverage)
BuildRequires:  python3dist(flake8)
BuildRequires:  python3dist(nose)
BuildRequires:  python3dist(numpy)
BuildRequires:  python3dist(pandas)
%endif

%description
tqdm derives from the Arabic word taqaddum (تقدّم) which can mean “progress,”
and is an abbreviation for “I love you so much” in Spanish (te quiero
demasiado).

Instantly make your loops show a smart progress meter - just wrap any iterable
with tqdm(iterable), and you’re done!


%package -n python3-%{pypi_name}
Summary:        %{summary}
%{?python_provide:%python_provide python3-%{pypi_name}}
Recommends:     python3dist(pandas)
Recommends:     python3dist(numpy)

%description -n python3-%{pypi_name}
tqdm derives from the Arabic word taqaddum (تقدّم) which can mean “progress,”
and is an abbreviation for “I love you so much” in Spanish (te quiero
demasiado).

Instantly make your loops show a smart progress meter - just wrap any iterable
with tqdm(iterable), and you’re done!

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

# https://github.com/tqdm/tqdm/pull/1292
echo 'include tqdm/tqdm.1' >> MANIFEST.in
echo 'include tqdm/completion.sh' >> MANIFEST.in

%generate_buildrequires
%pyproject_buildrequires -r

%build
%pyproject_wheel

%install
%pyproject_install
%pyproject_save_files %{pypi_name}

install -Dpm0644 \
  %{buildroot}%{python3_sitelib}/tqdm/tqdm.1 \
  %{buildroot}%{_mandir}/man1/tqdm.1

install -Dpm0644 \
  %{buildroot}%{python3_sitelib}/tqdm/completion.sh \
  %{buildroot}%{_datadir}/bash-completion/completions/tqdm.bash

rm -rf %{buildroot}%{python3_sitelib}/tqdm/tqdm.1
rm -rf %{buildroot}%{python3_sitelib}/tqdm/completion.sh
sed -i -e '/completion\.sh/d' -e '/tqdm\.1/d' %{pyproject_files}

%if %{with tests}
%check
%pytest
%endif

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license LICENCE
%doc README.rst examples
%{_bindir}/%{pypi_name}
%{_mandir}/man1/%{pypi_name}.1*
%{_datadir}/bash-completion/completions/tqdm.bash


%changelog
* Wed Jul 02 2025 umeabot <umeabot> 4.67.1-4.mga10
+ Revision: 2236187
- Mageia 10 Mass Rebuild

* Fri Feb 21 2025 wally <wally> 4.67.1-3.mga10
+ Revision: 2150502
- rebuild for python3.13

* Fri Dec 27 2024 papoteur <papoteur> 4.67.1-2.mga10
+ Revision: 2130494
- add and use pytest

* Thu Dec 26 2024 wally <wally> 4.67.1-1.mga10
+ Revision: 2130201
- new version 4.67.1

* Wed Aug 21 2024 daviddavid <daviddavid> 4.66.5-1.mga10
+ Revision: 2087212
- new version: 4.66.5

* Mon Jun 24 2024 papoteur <papoteur> 4.66.4-1.mga10
+ Revision: 2076425
- new version 4.66.4

* Sat Dec 09 2023 wally <wally> 4.64.1-3.mga10
+ Revision: 2016478
- rebuild for py3.12

* Fri Nov 04 2022 wally <wally> 4.64.1-2.mga9
+ Revision: 1902760
- update setuptools-scm BRs

* Sun Oct 23 2022 ghibo <ghibo> 4.64.1-1.mga9
+ Revision: 1898675
- Update to release 4.64.1

* Thu Sep 08 2022 neoclust <neoclust> 4.64.0-1.mga9
+ Revision: 1885718
- New version  4.64.0

* Thu Mar 24 2022 umeabot <umeabot> 4.62.3-2.mga9
+ Revision: 1824682
- Mageia 9 Mass Rebuild

* Sun Feb 06 2022 wally <wally> 4.62.3-1.mga9
+ Revision: 1772443
- new version 4.62.3
- rebuild for python3.10

* Sat Mar 20 2021 neoclust <neoclust> 4.55.0-2.mga9
+ Revision: 1705060
- Rebuild against python 3.9

* Wed Dec 30 2020 akien <akien> 4.55.0-1.mga8
+ Revision: 1665974
- Version 4.55.0, BR setuptools-scm[toml]

* Wed Dec 30 2020 akien <akien> 4.52.0-1.mga8
+ Revision: 1665937
- Down to version 4.52.0 (4.55.0 never built)
  4.53+ require pip and networking to setup dependencies...
- Version 4.55.0

* Thu Oct 29 2020 joequant <joequant> 4.51.0-1.mga8
+ Revision: 1640454
- update to 4.51.0

* Tue Feb 18 2020 umeabot <umeabot> 4.41.0-2.mga8
+ Revision: 1541779
- Mageia 8 Mass Rebuild

* Wed Jan 01 2020 wally <wally> 4.41.0-1.mga8
+ Revision: 1475171
- new version 4.41.0

* Tue Sep 17 2019 daviddavid <daviddavid> 4.29.1-3.mga8
+ Revision: 1442810
- rebuild for python3.8

* Mon Sep 16 2019 tv <tv> 4.29.1-2.mga8
+ Revision: 1442601
- rebuild for python-3.8
- drop python2 subpkg

* Sat Jan 12 2019 wally <wally> 4.29.1-1.mga7
+ Revision: 1355557
- new version 4.29.1
+ tmb <tmb>
- rebuild for python 3.7
+ tv <tv>
- rebuild with python 3.7

* Wed Dec 12 2018 akien <akien> 4.28.1-1.mga7
+ Revision: 1340504
- Version 4.28.1

* Fri Sep 21 2018 umeabot <umeabot> 4.15.0-2.mga7
+ Revision: 1290432
- Mageia 7 Mass Rebuild

* Sat Aug 26 2017 akien <akien> 4.15.0-1.mga7
+ Revision: 1148018
- Version 4.15.0

* Sat Aug 05 2017 pterjan <pterjan> 4.14.0-3.mga7
+ Revision: 1135668
- Rebuild for python 3.6

* Wed Jun 07 2017 akien <akien> 4.14.0-2.mga6
+ Revision: 1107226
- Skip perf tests with nose as they might fail on the BS

* Sat Jun 03 2017 akien <akien> 4.14.0-1.mga6
+ Revision: 1105878
- Version 4.14.0
- Version 4.11.2

* Sat Feb 11 2017 akien <akien> 4.11.1-1.mga6
+ Revision: 1085720
- Adapt for Mageia
- import python-tqdm from Fedora 26


* Fri Jan 20 2017 Igor Gnatenko <ignatenko@redhat.com> - 4.11.1-1
- Update to 4.11.1

* Mon Dec 19 2016 Miro Hrončok <mhroncok@redhat.com> - 4.10.0-2
- Rebuild for Python 3.6

* Sun Nov 13 2016 Igor Gnatenko <i.gnatenko.brain@gmail.com> - 4.10.0-1
- Update to 4.10.0

* Mon Oct 31 2016 Igor Gnatenko <ignatenko@redhat.com> - 4.9.0-1
- Update to 4.9.0

* Tue Aug 16 2016 Igor Gnatenko <ignatenko@redhat.com> - 4.8.3-1
- Update to 4.8.3

* Fri Jul 22 2016 Igor Gnatenko <ignatenko@redhat.com> - 4.7.6-1
- Update to 4.7.6

* Thu Jun 23 2016 Igor Gnatenko <ignatenko@redhat.com> - 4.7.4-1
- Initial package
